docs.rs failed to build glpk-sys-0.3.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
glpk-sys-0.2.0
glpk-sys
GLPK 5.0 bindings for Rust. Requires GLPK
headers and library to be installed (apt install libglpk-dev, dnf install glpk-devel, brew install glpk, or set GLPK_DIR).